@@ -1,9 +1,10 @@
 /*
  * tools/lib/basename.c
  *
- * Copyright (C) 1997 - 1999  Heinz Mauelshagen, Germany
+ * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
  *
  * March 1997
+ * January 2000
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -23,25 +24,31 @@
  *
  */
 
+/*
+ * Changelog
+ *
+ *    31/01/2000 - use debug_enter()/debug_leave()
+ *
+ */
+
 #include <liblvm.h>
 
-#if __GLIBC__ < 2
+#if __GLIBC__ < 2 || __GLIBC_MINOR__ > 0
 char *basename(char *path)
 {
-	char *base, *slash;
+	char *ret = NULL;
 
-	if (path == NULL)
-		return NULL;
-	base = slash = path;
-	while (*base != 0) {
-		if (*base == '/')
-			slash = base;
-		base++;
+	debug_enter ( "basename -- CALLED with path: \"%s\"\n", path);
+
+	if (path) {
+		ret = strrchr(path, '/');
+		if (!ret)
+			ret = path;
+		else
+			ret++;
 	}
 
-	if (slash == path)
-		return path;
-	else
-		return ++slash;
+	debug_leave ( "basename -- LEAVING with ret: \"%s\"\n", ret);
+	return ret;
 }
 #endif
