@@ -41,9 +41,7 @@ int lv_check_active ( char *vg_name, char *lv_name) {
    int ret = FALSE;
    lv_t *lv;
 
-#ifdef DEBUG
    debug_enter ( "lv_check_active -- CALLED\n");
-#endif
 
    if ( vg_name == NULL || lv_name == NULL || lv_check_name ( lv_name) < 0) {
       ret = -LVM_EPARAM;
@@ -52,8 +50,6 @@ int lv_check_active ( char *vg_name, char *lv_name) {
       else                            ret = FALSE;
    }
 
-#ifdef DEBUG
    debug_leave ( "lv_check_active -- LEAVING with ret: %d\n", ret);
-#endif
    return ret;
 }
