@@ -1,7 +1,7 @@
 /*
  * tools/lib/lv_le_remap.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Germany
+ * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
  *
  * October 1997
  * January 1999
@@ -40,15 +40,13 @@ int lv_le_remap ( vg_t *vg, le_remap_req_t *le_remap_req) {
    int ret = 0;
    char group_file[NAME_LEN];
 
-#ifdef DEBUG
    debug_enter ( "lv_le_remap -- CALLED\n");
-#endif
 
-   if ( vg == NULL || vg_check_name ( vg->vg_name) < 0 ||
-        le_remap_req == NULL) ret = -LVM_EPARAM;
-   else {
-      sprintf ( group_file, LVM_DIR_PREFIX "%s/group%c", vg->vg_name, 0);
-   
+   if ( vg == NULL || le_remap_req == NULL) ret = -LVM_EPARAM;
+   else if ( ( ret = vg_check_name ( vg->vg_name)) == 0) {
+      memset ( group_file, 0, sizeof ( group_file));
+      snprintf ( group_file, sizeof ( group_file) - 1,
+                 LVM_DIR_PREFIX "%s/group", vg->vg_name);
       if ( ( group = open ( group_file, O_RDWR)) == -1)
          ret = -LVM_ELV_LE_REMAP_OPEN;
       else if ( ioctl ( group, LE_REMAP, le_remap_req) == -1) ret = -errno;
@@ -56,8 +54,6 @@ int lv_le_remap ( vg_t *vg, le_remap_req_t *le_remap_req) {
       if ( group != -1) close ( group);
    }
 
-#ifdef DEBUG
    debug_leave ( "lv_le_remap -- LEAVING with ret: %d\n", ret);
-#endif
    return ret;
 }
