@@ -40,7 +40,9 @@ int lv_rename ( char *lv_name_new, lv_t *lv) {
         lv_check_consistency ( lv) < 0) {
       ret = -LVM_EPARAM;
    } else {
-      sprintf ( group_file, LVM_DIR_PREFIX "%s/group", lv->vg_name);
+      memset ( group_file, 0, sizeof ( group_file));
+      snprintf ( group_file, sizeof ( group_file) - 1,
+                             LVM_DIR_PREFIX "%s/group", lv->vg_name);
       strcpy ( req.lv_name, lv_name_new);
       req.lv = lv;
       if ( ( group = open ( group_file, O_RDONLY)) == -1)
