@@ -1,7 +1,7 @@
 /*
  * tools/lib/lvm_tab_lv_read_by_name.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Germany
+ * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
  *
  * Oktober-November 1997
  * May,June 1998
@@ -48,9 +48,7 @@ int lvm_tab_lv_read_by_name ( char *vg_name, char *lv_name, lv_t **lv) {
    int ret = 0;
    vg_t *vg = NULL;
 
-#ifdef DEBUG
    debug_enter ( "lvm_tab_lv_read_by_name -- CALLED lv_name: %s\n", lv_name);
-#endif
 
    if ( vg_name == NULL || lv_name == NULL || lv == NULL ||
         vg_check_name ( vg_name) < 0 ||
@@ -66,8 +64,6 @@ int lvm_tab_lv_read_by_name ( char *vg_name, char *lv_name, lv_t **lv) {
       }
    } else ret = -LVM_ELVM_TAB_LV_READ_BY_NAME_LVM_TAB_VG_READ_WITH_PV_AND_LV;
 
-#ifdef DEBUG
    debug_leave ( "lvm_tab_lv_read_by_name -- LEAVING with ret: %d\n", ret);
-#endif
    return ret;
 }
