@@ -1,7 +1,7 @@
 /*
  * tools/lib/lvm_tab_vg_check_exist_all_vg.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Germany
+ * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
  *
  * Oktober-November 1997
  * May,June 1998
@@ -52,6 +52,7 @@
 #include <liblvm.h>
 
 
+/* validates all vg_names directly */
 char **lvm_tab_vg_check_exist_all_vg ( void) {
    int i = 0, nv = 0;
    int ret = 0;
@@ -60,9 +61,7 @@ char **lvm_tab_vg_check_exist_all_vg ( void) {
    char **vg_name_ptr = NULL;
    char **vg_name_ptr_sav = NULL;
 
-#ifdef DEBUG
    debug_enter ( "lvm_tab_vg_check_exist_all_vg -- CALLED\n");
-#endif
 
    if ( data != NULL) {
       free ( data);
@@ -82,9 +81,11 @@ char **lvm_tab_vg_check_exist_all_vg ( void) {
                ret = -LVM_ELVM_TAB_VG_CHECK_EXIST_ALL_VG_REALLOC;
                goto lvm_tab_vg_check_exist_all_vg_end;
             } else vg_name_ptr_sav = NULL;
-            vg_name_ptr[nv] = &data[i];
+            if ( vg_check_name ( &data[i]) == 0) {
+               vg_name_ptr[nv] = &data[i];
+               nv++;
+            }
             i += strlen ( &data[i]) + 1;
-            nv++;
          }
          vg_name_ptr[nv] = NULL;
       }
@@ -99,10 +100,8 @@ lvm_tab_vg_check_exist_all_vg_end:
       if ( vg_name_ptr     != NULL)      free ( vg_name_ptr);
       else if ( vg_name_ptr_sav != NULL) free ( vg_name_ptr_sav);
    }
-#ifdef DEBUG
+
    debug_leave ( "lvm_tab_vg_check_exist_all_vg -- LEAVING with ret: %d\n",
                  ret);
-#endif
-
    return vg_name_ptr;
 }
