@@ -57,15 +57,11 @@ int lvm_tab_vg_remove ( char *vg_name) {
    char *dst = NULL;
    char *src = NULL;
 
-#ifdef DEBUG
    debug_enter ( "lvm_tab_vg_remove -- CALLED  vg_name: \"%s\"\n", vg_name);
-#endif
 
    if ( vg_name == NULL || vg_check_name ( vg_name) < 0) ret = -LVM_EPARAM;
    else if ( ( ret = lvm_tab_read ( &data, &size)) == 0) {
-#ifdef DEBUG
    debug ( "lvm_tab_vg_remove -- lvm_tab_read o.k.\n");
-#endif
       while ( i < size) {
          if ( strcmp ( &data[i], vg_name) == 0) break;
          i += strlen ( &data[i]) + 1;
@@ -84,14 +80,14 @@ int lvm_tab_vg_remove ( char *vg_name) {
          }
 
          if ( ( ret = lvm_tab_write ( data, size)) == 0) {
-            sprintf ( lvmtab, "%s/%s%c", LVMTAB_DIR, vg_name, 0);
+            memset ( lvmtab, 0, sizeof ( lvmtab));
+            snprintf ( lvmtab, sizeof ( lvmtab) - 1,
+                               "%s/%s", LVMTAB_DIR, vg_name);
             if ( unlink ( lvmtab) != 0) ret = -LVM_ELVM_TAB_VG_REMOVE_UNLINK;
          }
       }
    }
 
-#ifdef DEBUG
    debug_leave ( "lvm_tab_vg_remove -- LEAVING with ret: %d\n", ret);
-#endif
    return ret;
 }
