@@ -86,9 +86,11 @@ int lvm_check_uuid ( char *uuidstr) {
 
 char *lvm_show_uuid ( char *uuidstr) {
    int i, j;
-   static char uuid[NAME_LEN] = { 0, };
+   static char uuid[2*NAME_LEN] = { 0, };
 
-   memset ( uuid, 0, NAME_LEN);
+   if ( strlen ( uuidstr) > NAME_LEN) return NULL;
+
+   memset ( uuid, 0, sizeof ( uuid));
 
    i = 6;
    memcpy ( uuid, uuidstr, i);
@@ -101,7 +103,7 @@ char *lvm_show_uuid ( char *uuidstr) {
       i += 4;
    }
 
-   memcpy ( &uuid[i], uuidstr, 2 );
+   strcpy ( &uuid[i], uuidstr);
 
    return uuid;
 }
