@@ -1,11 +1,12 @@
 /*
  * tools/lib/pv_check_part.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 1997 - 2002  Heinz Mauelshagen, Sistina Software
  *
  * March,October,November 1997
  * January,August 1999
  * February 2000
+ * February 2002
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -33,6 +34,7 @@
  *    23/01/1999 - extension for devfs names
  *    15/08/1999 - rewritten based on lvm_dir_cache_find()
  *    31/01/2000 - use debug_enter()/debug_leave()
+ *    06/02/2002 - moved pv_check_partitioned_whole() here
  *
  */
 
@@ -42,9 +44,7 @@ int pv_check_part ( char *dev_name) {
    int ret = 0;
    dir_cache_t *cache_entry = NULL;
 
-#ifdef DEBUG
    debug_enter ( "pv_check_part -- CALLED with %s\n", dev_name);
-#endif
 
    if ( dev_name == NULL || pv_check_name ( dev_name) < 0) ret = -LVM_EPARAM;
    else {
@@ -55,8 +55,36 @@ int pv_check_part ( char *dev_name) {
       if ( ret < MIN_PART || ret > MAX_PART) ret = -LVM_EPV_CHECK_PART;
    }
 
-#ifdef DEBUG
    debug_leave ( "pv_check_part -- LEAVING with %d\n", ret);
-#endif
    return ret;
 }
+
+
+/* Check for partitions on this device if it's a whole disk */
+int pv_check_partitioned_whole(char *pv_name)
+{
+    kdev_t kdev;
+
+    kdev = pv_create_kdev_t(pv_name);
+    if (lvm_check_partitioned_dev(kdev)) {
+	dir_cache_t *dir_cache = NULL;
+	int dir_cache_count;
+	int i;
+	int partitions = lvm_partition_count(kdev);
+
+	if ( ( dir_cache_count = lvm_dir_cache ( &dir_cache)) < 1) {
+	    return -LVM_EPV_GET_SIZE_LVM_DIR_CACHE;
+	}
+
+	for ( i = 0; i < dir_cache_count; i++) {
+	    if (dir_cache[i].st_rdev - (dir_cache[i].st_rdev % partitions) == kdev &&
+		dir_cache[i].st_rdev != kdev) {
+		return -LVM_EPV_GET_SIZE_PART;
+	    }
+
+	}
+    }
+    return 0;
+}
+
+
