@@ -46,8 +46,9 @@ int pv_flush ( char *pv_name) {
    else {
       if ( stat ( pv_name, &stat_buf) == -1) ret = -LVM_EPV_FLUSH_STAT;
       else {
+         memset ( &req, 0, sizeof ( req));
          req.pv_dev = stat_buf.st_rdev;
-         strcpy ( req.pv_name, pv_name);
+         strncpy ( req.pv_name, pv_name, sizeof ( req.pv_name) - 1);
          if ( ( lvm = open ( LVM_DEV, O_RDONLY)) == -1)
             ret = -LVM_EPV_FLUSH_OPEN;
          else ret = ioctl ( lvm, PV_FLUSH, &req);
