@@ -45,9 +45,7 @@ int vg_check_online_all_pv ( vg_t *vg, pv_t ***pv_offl, pv_t ***pv_incons) {
    pv_t **pv_offl_this = NULL;
    pv_t **pv_incons_this = NULL;
 
-#ifdef DEBUG
    debug_enter ( "vg_check_online_all_pv -- CALLED\n");
-#endif
 
    if ( vg == NULL || pv_offl == NULL || pv_incons == NULL ||
         vg_check_consistency_with_pv_and_lv ( vg) < 0) {
@@ -71,10 +69,8 @@ int vg_check_online_all_pv ( vg_t *vg, pv_t ***pv_offl, pv_t ***pv_incons) {
    pv_offl_this[0] = pv_incons_this[0] = NULL;
 
    for ( p = 0; p < vg->pv_cur; p++) {
-#ifdef DEBUG
    debug ( "vg_check_online_all_pv -- before pv_read for %s\n",
             vg->pv[p]->pv_name);
-#endif
       if ( ( ret = pv_read ( vg->pv[p]->pv_name, &pv, NULL)) < 0) {
          if ( ret == -LVM_EPV_READ_PV_CREATE_NAME_FROM_KDEV_T)
             goto vg_check_online_all_pv_end;
@@ -104,8 +100,7 @@ int vg_check_online_all_pv ( vg_t *vg, pv_t ***pv_offl, pv_t ***pv_incons) {
    *pv_incons = pv_incons_this;
 
 vg_check_online_all_pv_end:
-#ifdef DEBUG
+
    debug_leave ( "vg_check_online_all_pv -- LEAVING with ret: %d\n", ret);
-#endif
    return ret;
 }
