@@ -39,19 +39,19 @@ int vg_remove_dir_and_group_and_nodes ( char *vg_name) {
    int ret = 0;
    char buffer[NAME_LEN+20];
 
-#ifdef DEBUG
    debug_enter ( "vg_remove_dir_and_group_and_nodes -- CALLED\n");
-#endif
 
-   if ( vg_name != NULL && vg_check_name ( vg_name) == 0) {
+   if ( vg_name == NULL || vg_check_name ( vg_name) < 0) ret = -LVM_EPARAM;
+   /* should be a warning, but i would have to catch it */
+   else if ( lvm_check_devfs()) ret = 0;
+   else {
       /* remove the volume group directory */
-      sprintf ( buffer, LVM_DIR_PREFIX "%s%c", vg_name, 0);
+      memset ( buffer, 0, sizeof ( buffer));
+      snprintf ( buffer, sizeof ( buffer) - 1, LVM_DIR_PREFIX "%s", vg_name);
       ret = lvm_remove_recursive ( buffer);
-   } else ret = -LVM_EPARAM;
+   }
 
-#ifdef DEBUG
    debug_leave ( "vg_remove_dir_and_group_and_nodes -- LEAVING with ret: %d\n",
                  ret);
-#endif
    return ret;
 }
