@@ -48,7 +48,9 @@ int vg_rename ( char *vg_name_old, char *vg_name_new) {
         vg_check_name ( vg_name_old) < 0 ||
         vg_check_name ( vg_name_new) < 0) ret = -LVM_EPARAM;
    else {
-      sprintf ( group_file, LVM_DIR_PREFIX "%s/group%c", vg_name_old, 0);
+      memset ( group_file, 0, sizeof ( group_file));
+      snprintf ( group_file, sizeof ( group_file) - 1,
+                             LVM_DIR_PREFIX "%s/group%c", vg_name_old, 0);
       strncpy ( vg_name_new_tmp, vg_name_new, sizeof ( vg_name_new_tmp) - 1);
       if ( ( group = open ( group_file, O_RDWR)) == -1)
          ret = -LVM_EVG_RENAME_OPEN;
