@@ -1,12 +1,13 @@
 /*
  * tools/lib/vg_setup_for_create.c
  *
- * Copyright (C) 1997 - 2001  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 1997 - 2002  Heinz Mauelshagen, Sistina Software
  *
  * March 1997
  * February 1998
  * January,September 2000
  * June 2001
+ * January-February 2002
  *
  *
  * This LVM library is free software; you can redistribute it and/or
@@ -39,6 +40,9 @@
  *    25/06/2001 - Round down pv_size when calculating the number of PEs it can hold
  *                 so that it leaves room for the VGDA.
  *    26/06/2001 - Better fix to make sure there's room for the VGDA
+ *    29/01/2002 - removed wrong check for ~64k PE max per PV
+ *    06/02/2002 - cope with changed pv_get_size() return cast
+ *    17/02/2002 - use pv_get_size_ll() for library compatibility
  *
  */
 
@@ -49,6 +53,8 @@ int vg_setup_for_create ( char *vg_name, vg_t *vg, pv_t **pv,
    int p = 0;
    int ret = 0;
    uint pe_total = 0;
+   long long pv_size;
+   uint size;
 
    debug_enter ( "vg_setup_for_create -- CALLED\n");
 
@@ -88,11 +94,18 @@ int vg_setup_for_create ( char *vg_name, vg_t *vg, pv_t **pv,
       pv_t *pp = pv[p];
 
       /* FIXME: surely we should be comparing (pv_size - VGDA size) ? [JT] */
-      if ( ( pp->pv_size = pv_get_size ( pp->pv_name, NULL)) / pe_size <
-           LVM_PE_SIZE_PV_SIZE_REL) {
-         ret = -LVM_EVG_SETUP_FOR_CREATE_PV_SIZE_MIN;
-         goto vg_setup_for_create_end;
+      if ( pv[p]->pv_size != 0) {
+         size = pv[p]->pv_size;
+      } else {
+         pv_size = pv_get_size_ll ( pp->pv_name, NULL);
+         size = pv_size;
+         if ( ( pv_size < 0) ||
+              ( size / pe_size < LVM_PE_SIZE_PV_SIZE_REL)) {
+            ret = -LVM_EVG_SETUP_FOR_CREATE_PV_SIZE_MIN;
+            goto vg_setup_for_create_end;
+         }
       }
+      pp->pv_size = size;
 
       vg->pv[p] = pp;
       strcpy ( pp->vg_name, vg->vg_name);
@@ -118,11 +131,6 @@ int vg_setup_for_create ( char *vg_name, vg_t *vg, pv_t **pv,
         ret = -LVM_EVG_SETUP_FOR_CREATE_PV_SIZE_MIN;
 	goto vg_setup_for_create_end;
       }
-      if(pp->pe_total > LVM_PE_T_MAX) {
-        debug("vg_setup_for_create - pe_total: %d LVM_PE_T_MAX: %d\n", pp->pe_total, LVM_PE_T_MAX);
-        ret = -LVM_EVG_SETUP_FOR_CREATE_PV_SIZE_MAX;
-	goto vg_setup_for_create_end;
-      }
 
       if ( ( pp->pe = malloc ( pp->pe_total * sizeof ( pe_disk_t))) == NULL) {
          fprintf ( stderr, "malloc error in %s [line %d]\n",
@@ -172,10 +180,9 @@ int setup_pe_table(pv_t *p)
 	if(!p->pe_total)
 		return 0;
 
-	p->pe_on_disk.size = pe_table_size * SECTOR_SIZE;
-
+	p->pe_on_disk.size = (pe_table_size + p->pe_size) * SECTOR_SIZE;
 	p->pe_start = div_up(p->pe_on_disk.base + p->pe_on_disk.size,
-			     SECTOR_SIZE) + p->pe_size;
+			     SECTOR_SIZE);
 
 	return 1;
 }
