@@ -1,12 +1,13 @@
 /*
  * tools/lvdisplay.c
  *
- * Copyright (C) 1997 - 2000  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 1997 - 2001  Heinz Mauelshagen, Sistina Software
  *
  * March 1997
  * May-June,August,September 1998
  * February,October,November 1999
  * February,November 2000
+ * March,July 2001
  *
  * LVM is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,6 +41,13 @@
  *    03/11/1999 - implemented option -c for colon seperated output
  *    15/02/2000 - use lvm_error()
  *    07/11/2000 - used LVM_VG_NAME environment variable
+ *    23/01/2001 - added call to lvm_init (JT)
+ *    06/03/2001 - removed misleading "(lvmtab)" string in display in
+ *                 case of -D (HM)
+ *               - changed inactivity checking in order to get data of
+ *                 deactivated logical volumes from kernel to display
+ *                 it as well (HM)
+ *    25/07/2001 - avoid misleading "(null)" in error message (AGK)
  *
  */
 
@@ -58,16 +66,10 @@ int main ( int argc, char **argv) {
    int opt_v = 0;
    int ret = 0;
    char *lv_name = NULL;
-#ifdef DEBUG
-   char *options = "cdDh?v";
-#else
-   char *options = "cDh?v";
-#endif
+   char *options = "cDh?v" DEBUG_SHORT_OPTION;
    struct option long_options[] = {
       { "colon",      no_argument,       NULL, 'c'},
-#ifdef DEBUG
-      { "debug",      no_argument,       NULL, 'd'},
-#endif
+      DEBUG_LONG_OPTION
       { "disk",       no_argument,       NULL, 'D'},
       { "help",       no_argument,       NULL, 'h'},
       { "verbose",    no_argument,       NULL, 'v'},
@@ -76,9 +78,9 @@ int main ( int argc, char **argv) {
    char *vg_name = NULL;
    lv_t *lv = NULL;
 
+   /* lvm_init(argc, argv); */
    cmd = basename ( argv[0]);
 
-   SUSER_CHECK;
    LVMTAB_CHECK;
 
    while ( ( c = getopt_long ( argc, argv, options,
@@ -92,15 +94,7 @@ int main ( int argc, char **argv) {
             opt_c++;
             break;
 
-#ifdef DEBUG
-         case 'd':
-            if ( opt_d > 0) {
-               fprintf ( stderr, "%s -- d option already given\n\n", cmd);
-               return LVM_EINVALID_CMD_LINE;
-            }
-            opt_d++;
-            break;
-#endif
+         DEBUG_HANDLE_CASE_D;
 
          case 'D':
             if ( opt_D > 0) {
@@ -117,11 +111,9 @@ int main ( int argc, char **argv) {
                      "---------\n\n"
                      "%s\n"
                      "\t[-c/--colon]\n"
-#ifdef DEBUG
-                     "\t[-d/--debug]\n"
-#endif
+                     DEBUG_HELP
                      "\t[-D/--disk]\n"
-                     "\t[-h/-?/--help]\n"
+                     "\t[-h/--help]\n"
                      "\t[-v[v]/--verbose [--verbose]]\n"
                      "\tLogicalVolume[Path] [LogicalVolume[Path]...]\n\n",
                      lvm_version, LVM_LIB_IOP_VERSION,  cmd, cmd);
@@ -164,6 +156,13 @@ int main ( int argc, char **argv) {
 
       LVM_CHECK_DEFAULT_VG_NAME ( lv_name, buffer, NAME_LEN);
 
+      if ( lv_name == NULL) {
+         fprintf ( stderr, "%s -- a path needs supplying for "
+                            "logical volume argument \"%s\"\n\n",
+                            cmd, argv[optind]);
+         continue;
+      }
+
       if ( opt_v > 1) printf ( "%s -- checking logical volume name \"%s\"\n",
                                cmd, lv_name);
       if ( ( ret = lv_check_name ( lv_name)) < 0) {
@@ -184,19 +183,20 @@ int main ( int argc, char **argv) {
          continue;
       }
    
-      if ( opt_v > 1) printf ( "%s -- checking logical volume activity "
-                               "of \"%s\"\n", cmd, lv_name);
-      if ( lv_check_active ( vg_name, lv_name) != TRUE && opt_D == 0) {
-         fprintf ( stderr, "%s -- logical volume \"%s\" is not active; "
-                           "try -D\n\n", cmd, lv_name);
+      if ( opt_v > 1) printf ( "%s -- checking volume group activity "
+                               "of \"%s\"\n", cmd, vg_name);
+      if ( vg_check_active ( vg_name) != TRUE && opt_D == 0) {
+         fprintf ( stderr, "%s -- volume group \"%s\" of logical volume \"%s\""
+                           "is not active\n%s -- try -D, please\n\n",
+                           cmd, vg_name, lv_name, cmd);
          continue;
       }
-   
+
       if ( opt_v > 1) printf ( "%s -- getting logical volume data for \"%s\" "
                                "from ", cmd, lv_name);
       /* from disk(s) */
       if ( opt_D > 0) {
-         if ( opt_v > 1) printf ( "disk (lvmtab)\n");
+         if ( opt_v > 1) printf ( "DISK\n");
          if ( ( ret = lv_read_with_pe ( vg_name, lv_name, &lv)) < 0) {
             fprintf ( stderr, "%s -- ERROR \"%s\" no VALID logical volume "
                               "\"%s\"\n\n",
@@ -207,7 +207,7 @@ int main ( int argc, char **argv) {
                                   cmd);
       /* from kernel */
       } else {
-         if ( opt_v > 1) printf ( "kernel\n");
+         if ( opt_v > 1) printf ( "KERNEL\n");
          if ( ( ret = lv_status_byname ( vg_name, lv_name, &lv)) < 0) {
             if ( ret == -LVM_ELV_STATUS_INTERNAL_OPEN ||
                  ret == -ENXIO) {
