@@ -64,7 +64,7 @@ int main ( int argc, char **argv)
    char buffer[NAME_LEN];
    char *options = "A:fh?v" DEBUG_SHORT_OPTION;
    struct option long_options[] = {
-      { "autobackup", no_argument, NULL, 'A'},
+      { "autobackup", required_argument, NULL, 'A'},
       DEBUG_LONG_OPTION
       { "force",      no_argument, NULL, 'f'},
       { "help",       no_argument, NULL, 'h'},
