@@ -140,8 +140,8 @@ int main ( int argc, char **argv)
    }
 
    if ( argc == 0) {
-      printf ( "%s -- no volume groups found", cmd);
-      usage ( LVM_EINVALID_CMD_LINE);
+      printf ( "%s -- no volume groups found\n", cmd);
+      exit (0);
    }
 
    LVM_CHECK_IOP;
