@@ -1,7 +1,7 @@
 /*
  * tools/vgscan.c
  *
- * Copyright (C) 1997 - 2001  Heinz Mauelshagen, Sistina Software
+ * Copyright (C) 1997 - 2003  Heinz Mauelshagen, Sistina Software
  *
  * Oktober  1997
  * January  1998
@@ -9,6 +9,7 @@
  * May,July,October,November 1999
  * February,July 2000
  * January,March,October 2001
+ * September 2003
  *
  * LVM is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -51,6 +52,7 @@
  *    12/03/2001 - ensured that empty lvmtab is created first (HM)
  *    05/10/2001 - tidy usage() (HM)
  *    24/10/2001 - support for persistent VG/LV numbers (HM)
+ *    02/09/2003 - fixed -f bug assigning wrong minor numbers to LVs (HM)
  *
  */
 
@@ -299,33 +301,31 @@ int main ( int argc, char **argv)
                for ( blk_dev = l = 0; l < vg->lv_max; l++) {
                   lv = vg->lv[l];
                   if ( lv == NULL) continue;
-                  if ( lvm_tab_check_free_lv_number ( lv) == FALSE) {
-                     printf ( "%s -- changing minor number on \"%s\"\n",
-                              cmd, lv->lv_name);
-                     if ( lv->lv_access & LV_SNAPSHOT_ORG) {
-                        int ll;
-                        for ( ll = 0; ll < vg->lv_max; ll++) {
-                           lv_t *lv1 = vg->lv[ll];
-                           if ( lv1 == NULL || lv1 == lv) continue;
-                           if ( lv1->lv_access & LV_SNAPSHOT &&
-                                lv1->lv_snapshot_minor == MINOR(lv->lv_dev)) {
-                              printf ( "%s -- correcting snapshot "
-                                       "relationship of \"%s\"\n",
-                                       cmd, lv1->lv_name);
-                              lv1->lv_snapshot_minor =
-                                 MINOR ( blk_dev_free[blk_dev]);
-                           }
+                  printf ( "%s -- changing minor number on \"%s\"\n",
+                           cmd, lv->lv_name);
+                  if ( lv->lv_access & LV_SNAPSHOT_ORG) {
+                     int ll;
+                     for ( ll = 0; ll < vg->lv_max; ll++) {
+                        lv_t *lv1 = vg->lv[ll];
+                        if ( lv1 == NULL || lv1 == lv) continue;
+                        if ( lv1->lv_access & LV_SNAPSHOT &&
+                             lv1->lv_snapshot_minor == MINOR(lv->lv_dev)) {
+                           printf ( "%s -- correcting snapshot "
+                                    "relationship of \"%s\"\n",
+                                    cmd, lv1->lv_name);
+                           lv1->lv_snapshot_minor =
+                              MINOR ( blk_dev_free[blk_dev]);
                         }
                      }
-                     lv->lv_dev = blk_dev_free[blk_dev++];
-                     change++;
-                     if ( blk_dev == blk_dev_free_count) {
-                        fprintf ( stderr,
-                                  "%s -- run out of free block devices "
-                                  "(only %d were available)\n\n",
-                                  cmd, blk_dev_free_count);
-                        return LVM_EVGSCAN_NO_DEV;
-                     }
+                  }
+                  lv->lv_dev = blk_dev_free[blk_dev++];
+                  change++;
+                  if ( blk_dev == blk_dev_free_count) {
+                     fprintf ( stderr,
+                               "%s -- run out of free block devices "
+                               "(only %d were available)\n\n",
+                               cmd, blk_dev_free_count);
+                     return LVM_EVGSCAN_NO_DEV;
                   }
                }
             }
